#
# spec file for package alacritty
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alacritty
Version:        0.12.2
Release:        1.1
Summary:        A GPU-accelerated terminal emulator
License:        Apache-2.0
URL:            https://github.com/alacritty/alacritty
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source3:        README.suse-maint
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  freetype-devel
BuildRequires:  libxcb-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xclip
BuildRequires:  pkgconfig(fontconfig)
Suggests:       terminfo

%description
Alacritty is a terminal emulator written in Rust that leverages the GPU for
rendering.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
The official bash completion script for alacritty. It includes support
for every argument that can currently be passed to alacritty.

%package fish-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for alacritty.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for alacritty.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%ifarch aarch64 ppc64le riscv64
# Remove checksum of config.guess and config.sub since aarch64 and ppc64le modify them
sed -i 's#"expat/conftools/config.guess":"ebaffe1c6683ae2c3dcabb87825a83b892f00391514756f7640c4a3dcafbad4f",##g' ./vendor/expat-sys/.cargo-checksum.json
sed -i 's#"expat/conftools/config.sub":"523cb028db907d1fbbcecdcac6737f9e2eeba48fb639231dbc5ae69238f276c9",##g' ./vendor/expat-sys/.cargo-checksum.json
%endif
%ifarch riscv64
sed -i -e 's#"config.guess":"e0c1d7ef8ce964fb57c35e7704ae8661d7e4ca87d6a3c18950e503ae26b62319",##' -e 's#"config.sub":"f7e62c3cb15cd5bbc4e7f3617793b227481fc554d39697a9c322a266d20fb626",##' vendor/servo-fontconfig-sys/.cargo-checksum.json
%endif

%build
%{cargo_build}

%install
mkdir -p "%{buildroot}%{_bindir}"
install -D -m 0755 target/release/alacritty %{buildroot}%{_bindir}/alacritty

# rm duplicate license and useless toml file
rm -fr %{buildroot}%{_datadir}

# install man page and completions
install -Dm 0644 extra/linux/Alacritty.desktop \
    %{buildroot}/%{_datadir}/applications/Alacritty.desktop
install -Dm 0644 extra/logo/alacritty-simple.svg \
    %{buildroot}/%{_datadir}/pixmaps/Alacritty.svg
install -Dm 0644 extra/linux/org.alacritty.Alacritty.appdata.xml \
    %{buildroot}/%{_datadir}/appdata/org.alacritty.Alacritty.appdata.xml
install -Dm 0644 extra/%{name}.man %{buildroot}/%{_mandir}/man1/%{name}.1
install -Dm 0644 extra/completions/%{name}.bash \
    %{buildroot}/%{_datadir}/bash-completion/completions/%{name}
install -Dm 0644 extra/completions/%{name}.fish \
    %{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm 0644 extra/completions/_%{name} \
    %{buildroot}/%{_datadir}/zsh/site-functions/_%{name}

# install desktop file
%suse_update_desktop_file Alacritty

%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE-APACHE
%doc alacritty.yml CHANGELOG.md CONTRIBUTING.md README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/Alacritty.desktop
%{_datadir}/pixmaps/Alacritty.svg
%{_datadir}/appdata/org.alacritty.Alacritty.appdata.xml

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Tue Jul  4 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.12.2:
  * Fix the crash when shrinking scrolled terminal
  * Fix freeze with some drivers when using GLX
  * Fix hyperlink preview for 2 lines terminal
  * Bump `actions/checkout` to v3
* Sun Jun 18 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Make terminfo package a suggested dependency
- Do not install terminfo anymore
* Fri Jun 16 2023 Luciano Santos <luc14n0@opensuse.org>
- Install forgotten terminfo database entry, so software can have
  access to information about Alacritty's capabilities.
- Drop no longer needed rustflags/RUSTFLAGS macro/variable
  definition in spec file, as the macros provided by
  cargo-packaging already define and make use of them for us.
- Update README.suse-maint to show newcomers how to update the
  package with current sensible packaging practices.
* Mon May 29 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.12.1:
  * Fixed
    + Very long startup times on Wayland systems with broken
    xdg-portal setup
    + Error on startup with GLX when using old mesa platforms
    + Character ; inside the URI in OSC 8 sequence breaking the URI
    + Selection on last line not updating correctly on resize
* Sat Mar 25 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Disable source services again
* Sat Mar 25 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.12.0:
  * Added
    + Uppercase -T short form for --title
    + Support for horizontal scrolling in mouse mode and
    alternative scrolling modes
    + Support for fractional scaling on Wayland with
    wp-fractional-scale protocol
    + Support for running on GLES context
    + Touchscreen input for click/scroll/select/zoom
    + window.resize_increments config option, disabled by default
  * Changed
    + Erase in line after the last column will no longer clear the
    last column
    + Open new windows by default with macOS Cmd+N binding
    + The hint about window transparency is now properly issued on
    Wayland and macOS
    + The IME purpose is now set to Terminal which could help with
    OSK
    + window.decorations_theme_variant is now using Dark, Light,
    and None values
    + Resize increments are now set on macOS and X11 to resize by
    cell sizes
  * Fixed
    + --help output for --class does not match man pages
    + Cursor and underlines always being black on very old hardware
    + Crash when using very low negative font.offset
    + Artifacts in corners for maximized window with CSD on Wayland
    + Dotted underline not shown on macOS
    + Crash with OT-SVG fonts on Linux/BSD
    + Crash during text compose on old GNOME under Wayland
    + Blurry fonts when changing padding size at runtime
    + Crash while typing on Wayland
    + Multi-line semantic bracket selection
    + Reduced GPU memory usage
    + Low frame rate when multiple windows render at the same time
    + Redraw hanging until a keypress on X11 in rare cases
    + Quadrants not aligned with half blocks with built-in font
    + EOT (\x03) escaping bracketed paste mode
    + Drag & Drop not working for the search bar
  * Removed
    + window.gtk_theme_variant config field; use
    window.decorations_theme_variant instead
    + alt_send_esc is now always set to true
- Enable source services
* Wed Jan 25 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add back the config.guess/config.sub workaround for aarch64,
  ppc64le and riscv64, which was silently dropped from previous
  commit.
* Wed Dec  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.11.0:
  * Packaging
  - Minimum Rust version has been bumped to 1.57.0
  - Renamed io.alacritty.Alacritty.appdata.xml to org.alacritty.Alacritty.appdata.xml
  - Renamed io.alacritty to org.alacritty for Alacritty.app
  * Fixed
  - Creating the IPC socket failing if WAYLAND_DISPLAY contains an absolute path
  - Crash when resetting the terminal while in vi mode
  - font.glyph_offset not live reloading
  - Failure when running on 10-bit color system
  - The colors being slightly different when using srgb displays on macOS
  - Vi cursor blinking not reset when navigating in search
  - Scrolling and middle-clicking modifying the primary selection
  - Bottom gap for certain builtin box drawing characters
  - Incorrect built-in glyphs for U+2567 and U+2568
  - Character mappings in the DEC special graphics character set (line drawing)
  - Window flickering on resize on Wayland
  - Unnecessary config reload when using /dev/null as a config file
  - Windows Open Alacritty Here on root of drive displaying error
  - On macOS, font.use_thin_strokes did not work since Big Sur
  - On macOS, trying to load a disabled font would crash
  - On macOS, Alacritty sessions did not appear in the list of tty sessions for w and who
  - Cursor not hiding on GNOME Wayland
  - Font having different scale factor after monitor powering off/on on X11
  - Viewport not updating after opening a new tabbed window on macOS
  - Terminal not exiting sometimes after closing all windows on macOS
  - CPU usage spikes due to mouse movements for unfocused windows on X11/Windows
  - First window on macOS not tabbed with system prefer tabs setting
  - Window being treaten as focused by default on Wayland
  * Removed
  - font.use_thin_strokes config field; to use thin strokes on macOS, set
  - AppleFontSmoothing to 0 with $ defaults write -g AppleFontSmoothing -int 0
- Add _constraints file. 8GB of RAM to build alacritty
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sun Feb 27 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.10.1
  * feat: Option font.builtin_box_drawing to disable the built-in
    font for drawing box characters
  * refactor: Builtin font thickness is now based on cell width
    instead of underline thickness
  * fix: Builtin font lines not contiguous when font.offset is used
  * fix: font.glyph_offset is no longer applied on builtin font
  * fix: Built-in font arcs alignment
  * fix: Colors being slightly off when using
    colors.transparent_background_colors
  * fix: OSC 4 not handling
  * fix: in OSC strings reporting default colors instead of
    modified ones
  * fix: OSC 104 not clearing colors when second parameter is empty
* Thu Feb  3 2022 JL K <me@jlk.one>
- Pin rustflags via specfile
- Update to version 0.10.0
  * feat: Option colors.transparent_background_colors to allow
    applying opacity to all background colors
  * feat: Support for running multiple windows from a single
    Alacritty instance (see docs/features.md)
  * feat: Urgency support on Wayland via xdg_activation_v1
  * refactor: ExpandSelection is now a configurable mouse binding
    action
  * refactor: Config option background_opacity, you should use
    window.opacity instead
  * refactor: Reload configuration files when their symbolic link
    is replaced
  * refactor: Strip trailing whitespaces when yanking from a block
    selection
  * refactor: Display area keeps history position when viewport is
    cleared
  * refactor: Commands spawn from the current directory of the
    foreground shell in Unix-like systems
  * refactor: Remove trailing newline from strings taken from hints
    or simple/semantic selections
  * refactor: Builtin font is now used for box drawing characters
    from U+2500 to U+259f
  * refactor: Logs now print the time since startup instead of the
    local time
  * fix: Line indicator obstructing vi mode cursor when scrolled
    into history
  * fix: Vi mode search starting in the line below the vi cursor
  * fix: Invisible cursor with matching foreground/background
    colors
  * fix: Crash when hovering over a match emptied by
    post-processing
  * fix: Crash when the vi cursor is on the scrollback and viewport
    clear is invoked
  * fix: Freeze when the vi cursor is on the scrollback and
    scrollback clear is invoked
  * fix: Vi cursor on topmost of the display moving downward when
    scrolled into history with active output
  * fix: Input lag on Wayland with Nvidia binary driver
  * fix: Crash when hovering the mouse over fullwidth characters
  * fix: Do not create logfile if the file already exists
* Wed Dec 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Restore the removing of the checksum of config.guess and
  config.sub for architectures that modify them.
  It was wrongly dropped with previous commit.
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Mon Aug  9 2021 Aleksa Sarai <asarai@suse.com>
- Update to version 0.9.0.
  * pkg: Minimum Rust version has been bumped to 1.46.0
  * feat: Support for ipfs/ipns URLs
  * feat: Mode field for regex hint bindings
  * fix: Regression in rendering performance with dense grids since 0.6.0
  * fix: Crash/Freezes with partially visible fullwidth characters due to alt screen resize
  * fix: Incorrect vi cursor position after invoking ScrollPage* action
  * fix: Slow PTY read performance with extremely dense grids
  * fix: Crash when resizing during vi mode
  * fix: Unintentional text selection range change after leaving vi mode
  * fix: Deadlock on Windows during high frequency output
  * fix: Search without vi mode not starting at the correct location when scrolled into history
  * fix: Crash when starting a vi mode search from the bottommost line
  * fix: Original scroll position not restored after canceling search
  * fix: Clipboard copy skipping non-empty cells when encountering an interrupted tab character
  * fix: Vi mode cursor moving downward when scrolled in history with active output
  * fix: Crash when moving fullwidth characters off the side of the terminal in insert mode
  * fix: Broken bitmap font rendering with FreeType 2.11+
  * fix: Crash with non-utf8 font paths on Linux
  * fix: Newly installed fonts not rendering until Alacritty restart
* Thu May 20 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.8.0
  * feat: IME composition preview not appearing on Windows
  * feat: Synchronized terminal updates using DCS = 1 s ST/DCS = 2 s ST
  * feat: Regex terminal hints (see features.md)
  * feat: macOS keybinding (cmd+alt+H) hiding all windows other than alacritty
  * feat: Support for magnet URLs
  * change: The vi mode cursor is now created in the top-left if the terminal
    cursor is invisible
  * change: Focused search match will use cell instead of match colors
    for CellForeground/CellBackground
  * change: URL highlighting has moved from mouse.url to the hints
    config section
  * fix: alacritty failing to start on X11 with invalid DPI reported by XRandr
  * fix: Text selected after search without any match
  * fix: Incorrect vi cursor position after leaving search
  * fix: Clicking on URLs on Windows incorrectly opens File Explorer
  * fix: Incorrect underline cursor thickness on wide cell
  * fix: Viewport moving around when resizing while scrolled into history
  * fix: Block cursor not expanding across fullwidth characters when
    on the right side of it
  * fix: Overwriting fullwidth characters only clearing one of the involved cells
* Sat Feb 20 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.7.2
  * shell completions: remove obsolete options
  * shell compeltions: add the -o/-option setting
  * fix: Crash due to assertion failure on 32-bit architectures
  * fix: Segmentation fault on shutdown with Wayland
  * fix: Incorrect estimated DPR with Wayland
  * fix: Consecutive clipboard stores dropped on Wayland until the
    application is refocused
- ran spec-cleaner
* Sat Jan 16 2021 Matthias Eliasson <elimat@opensuse.org>
- Make use of mktemp in revendor_source.sh script so we don't have a
  predictable working directory (boo#1180782)
* Mon Jan 11 2021 Andreas Schwab <schwab@suse.de>
- Fix build on riscv64
* Sat Jan  9 2021 Matthias Eliasson <elimat@opensuse.org>
- Update to version 0.7.1
  * Fixed
  - Jumping between matches in backward vi search
* Sun Jan  3 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.7.0-rc2
  + Support for ~/ at the beginning of configuration file imports
  + New cursor.style.blinking option to set the default blinking state
  + New cursor.blink_interval option to configure the blinking frequency
  + Support for cursor blinking escapes (CSI ? 12 h, CSI ? 12 l and CSI Ps SP q)
  + Customizable keybindings for search
  + History for search mode, bound to ^P/^N/Up/Down by default
  + Default binding to cancel search on Ctrl+C
  + History position indicator for search and vi mode
  * Nonexistent config imports are ignored instead of raising an error
  * Value for disabling logging with config.log_level is Off instead of None
  * Missing glyph symbols are no longer drawn for zerowidth characters
  * Bug fixes
  - Wide characters sometimes being cut off
  - Preserve vi mode across terminal reset
  - Escapes CSI Ps b and CSI Ps Z with large parameters locking up Alacritty
  - Dimming colors which use the indexed CSI 38 : 5 : Ps m notation
  - Slow rendering performance with a lot of cells with underline/strikeout attributes
  - Performance of scrolling regions with offset from the bottom
  - Compilation when targetting aarch64 on Apple
  - Cursor position not reported to apps when mouse is moved with button held outside of window
  - No live config update when starting Alacritty with a broken configuration file
  - PTY not drained to the end with the --hold flag enabled
  - Alacritty not discarding invalid escape sequences starting with ESC
  - Underline cursor being obscured by underline
  - Cursor not being rendered with a lot of unicode glyphs visible
  - IME input swallowed after triggering a key binding
  - Search without vi mode not jumping properly between all matches
  * Several Wayland fixes:
  - Extra mouse buttons are no longer ignored
  - Numpad arrow keys are now properly recognized
  - Crash due to clipboard not being properly released
  - Crash due to non-standard fontconfig configuration
  * The following CLI arguments have been removed in favor of the --option flag:
  - -persistent-logging
  - -live-config-reload
  - -no-live-config-reload
  - -dimensions
  - -position
    live-shader-reload feature
  * Config option dynamic_title, you should use window.dynamic_title instead
  * Config option scrolling.faux_multiplier, which was replaced by escape CSI ? 1007 h/l
- Packaging optimizations
  * pull sources with exclusions
  * add revendor_source.sh to remove unecessary objects from vendor tarball
* Fri Dec  4 2020 Avindra Goolcharan <avindra@opensuse.org>
- Use rust-packaging macros for vendoring dependencies
- remove cargo_config
* Wed Nov 25 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 0.6.0
  Packaging
  * Minimum Rust version has been bumped to 1.43.0
  * The snapcraft.yaml file has been removed
  * Updated setab/setaf capabilities in alacritty-direct to use colons
  * WinPTY is now enabled only when targeting MSVC
  * Deprecated the WinPTY backend feature, disabling it by default
  Added
  * Secondary device attributes escape (CSI > 0 c)
  * Support for colon separated SGR 38/48
  * New Ctrl+C binding to cancel search and leave vi mode
  * Escapes for double underlines (CSI 4 : 2 m) and underline reset
    (CSI 4 : 0 m)
  * Configuration file option for sourcing other files (import)
  * CLI parameter --option/-o to override any configuration field
  * Escape sequences to report text area size in pixels (CSI 14 t) and in
    characters (CSI 18 t)
  * Support for single line terminals dimensions
  * Right clicking on Wayland's client side decorations will show application menu
  * Escape sequences to enable and disable window urgency hints
    (CSI ? 1042 h, CSI ? 1042 l)
  Changed
  * Cursors are now inverted when their fixed color is similar to the
    cell's background
  * Use the working directory of the terminal foreground process,
    instead of the shell's working directory, for SpawnNewInstance action
  * Fallback to normal underline for unsupported underline types in CSI 4 : ? m escapes
  * The user's background color is now used as the foreground for the render timer
  * Use yellow/red from the config for error and warning messages instead of fixed colors
  * Existing CLI parameters are now passed to instances spawned using SpawnNewInstance
  * Wayland's Client side decorations now use the search bar colors
  * Reduce memory usage by up to at least 30%% with a full scrollback buffer
  * The number of zerowidth characters per cell is no longer limited to 5
  * SpawnNewInstance is now using the working directory of the terminal
    foreground process on macOS
  Fixed
  * Incorrect window location with negative window.position config options
  * Slow rendering performance with HiDPI displays, especially on macOS
  * Keys swallowed during search when pressing them right before releasing backspace
  * Crash when a wrapped line is rotated into the last line
  * Selection wrapping to the top when selecting below the error/warning bar
  * Pasting into clients only supporting UTF8_STRING mime type on Wayland
  * Crash when copying/pasting with neither pointer nor keyboard focus on Wayland
  * Crash due to fd leak on Wayland
  * IME window position with fullwidth characters in the search bar
  * Selection expanding over 2 characters when scrolled in history with fullwidth
    characters in use
  * Selection scrolling not starting when mouse is over the message bar
  * Incorrect text width calculation in message bar when the message contains
    multibyte characters
  * Remapped caps lock to escape not triggering escape bindings on Wayland
  * Crash when setting overly long title on Wayland
  * Switching in and out of various window states, like Fullscreen, not persisting
    window size on Wayland
  * Crash when providing 0 for XCURSOR_SIZE on Wayland
  * Gap between window and server side decorations on KWIN Wayland
  * Wayland's client side decorations not working after tty switch
  * Fullscreen startup mode not working on Wayland
  * Window not being rescaled when changing DPR of the current monitor on Wayland
  * Crash in some cases when pointer isn't presented upon startup on Wayland
  * IME not working on Wayland
  * Crash on startup on GNOME since its 3.37.90 version on Wayland
  * Touchpad scrolling scrolled less than it should on macOS/Wayland on scaled outputs
  * Incorrect modifiers at startup on X11
  * Add and Subtract keys are now named NumpadAdd and NumpadSubtract respectively
  * Feature checking when cross compiling between different operating systems
  * Crash when writing to the clipboard fails on Wayland
  * Crash with large negative font.offset.x/y
  * Visual bell getting stuck on the first frame
  * Zerowidth characters in the last column of the line
* Sun Aug  2 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to 0.5.0
  Packaging:
  * Minimum Rust version has been bumped to 1.41.0
  * Prebuilt Linux binaries have been removed
  * Added manpage, terminfo, and completions to macOS application bundle
  * On Linux/BSD the build will fail without Fontconfig installed, instead of
    building it from source
  Added:
  * Default Command+N keybinding for SpawnNewInstance on macOS
  * Vi mode for regex search, copying text, and opening links
  * CopySelection action which copies into selection buffer on Linux/BSD
  * Option cursor.thickness to set terminal cursor thickness
  * Font fallback on Windows
  * Support for Fontconfig embolden and matrix options
  * Opt-out compilation flag winpty to disable WinPTY support
  * Scrolling during selection when mouse is at top/bottom of window
  * Expanding existing selections using single, double and triple click with
    the right mouse button
  * Support for gopher and gemini URLs
  * Unicode 13 support
  * Option to run command on bell which can be set in bell.command
  Changed:
  * Block cursor is no longer inverted at the start/end of a selection
  * Preserve selection on non-LMB or mouse mode clicks
  * Wayland client side decorations are now based on config colorscheme
  * Low resolution window decoration icon on Windows
  * Mouse bindings for additional buttons need to be specified as a number
    not a string
  * Don't hide cursor on modifier press with mouse.hide_when_typing enabled
  * Shift + Backspace now sends ^? instead of ^H
  * Default color scheme is now Tomorrow Night with the bright colors of
    Tomorrow Night Bright
  * Set IUTF8 termios flag for improved UTF8 input support
  * Dragging files into terminal now adds a space after each path
  * Default binding replacement conditions
  * Adjusted selection clearing granularity to more accurately match content
  * To use the cell's text color for selection with a modified background,
    the color.selection.text
  * variable must now be set to CellForeground instead of omitting it
  * URLs are no longer highlighted without a clearly delimited scheme
  * Renamed config option visual_bell to bell
  * Moved config option dynamic_title to window.dynamic_title
  Fixed:
  * Selection not cleared when switching between main and alt grid
  * Freeze when application is invisible on Wayland
  * Paste from some apps on Wayland
  * Slow startup with Nvidia binary drivers on some X11 systems
  * Display not scrolling when printing new lines while scrolled in history
  * Regression in font rendering on macOS
  * Scroll down escape (CSI Ps T) incorrectly pulling lines from history
  * Dim escape (CSI 2 m) support for truecolor text
  * Incorrectly deleted lines when increasing width with a prompt wrapped
    using spaces
  * Documentation for class in --help missing information on setting general
    class
  * Linewrap tracking when switching between primary and alternate screen
    buffer
  * Preservation of the alternate screen's saved cursor when swapping to
    primary screen and back
  * Reflow of cursor during resize
  * Cursor color escape ignored when its color is set to inverted in the
    config
  * Fontconfig's autohint and hinting options being ignored
  * Ingoring of default FreeType properties
  * Alacritty crashing at startup when the configured font does not exist
  * Font size rounding error
  Removed:
  * Environment variable RUST_LOG for selecting the log level
  * Deprecated window.start_maximized config field
  * Deprecated render_timer config field
  * Deprecated persistent_logging config field
* Sat Jun  6 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to 0.4.3
- Fixed
  * Tabstops not being reset with reset
  * Fallback to LC_CTYPE=UTF-8 on macOS without valid system locale
  * Resize lag on launch under some X11 wms
  * Increased input latency due to vsync behavior on X11
  * Emoji colors blending with terminal background
  * Fix escapes prematurely terminated by terminators in unicode glyphs
  * Incorrect location when clicking inside an unfocused window on macOS
  * Startup mode Maximized on Windows
  * Crash when writing a fullwidth character in the last column with auto-wrap mode disabled
  * Crashing at startup on Windows
- run spec-cleaner
* Mon Mar 30 2020 Martin Rey <mrey@suse.com>
- Update to 0.4.2
  * Minimum Rust version has been bumped to 1.37.0
  * Capitalized the Alacritty.desktop file
- Added
  * Live config reload for window.title
  * Added Rust features x11 and wayland to pick backends, with both
    enabled by default
- Changed
  * Pressing additional modifiers for mouse bindings will no longer
    trigger them
  * Renamed WINIT_HIDPI_FACTOR environment variable to
    WINIT_X11_SCALE_FACTOR
  * Print an error instead of crashing, when startup working
    directory is invalid
  * Line selection will now expand across wrapped lines
  * The default value for draw_bold_text_with_bright_colors is now
    false
  * Mirror OSC query terminators instead of always using BEL
  * Increased Beam, Underline, and Hollow Block cursors' line
    widths
  * Dynamic title is not disabled anymore when window.title is set
    in config
- Removed
  * Config option auto_scroll, which is now always disabled
  * Config option tabspaces, which is now fixed at 8
- Fixed
  * Semantic selection stopping at full-width glyphs
  * Full-width glyphs cut off in last column
  * Crash when starting on some X11 systems
  * Font size resetting when Alacritty is moved between screens
  * Limited payload length in clipboard escape (used for Tmux
    copy/paste)
  * Alacritty not ignoring keyboard events for changing WM focus on
    X11
  * CLI parameters discarded when config is reload
  * Blurred icons in KDE task switcher (alacritty.ico is now
    high-res)
  * Block selection starting from first column after beginning
    leaves the scrollback
  * Incorrect selection status of the first cell when selection is
    off screen
  * Backwards bracket selection
  * Stack overflow when printing shader creation error
  * Underline position for bitmap fonts
  * Selection rotating outside of scrolling region
  * Throughput performance problems caused by excessive font metric
    queries
  * Unicode throughput performance on Linux/BSD
  * Resize of bitmap fonts
  * Crash when using bitmap font with embeddedbitmap set to false
  * Inconsistent fontconfig fallback
  * Handling of OpenType variable fonts
  * Expansion of block-selection on partially selected full-width
    glyphs
  * Handling of URLs with single quotes
  * Parser reset between DCS escapes
  * Parser stopping at unknown DEC private modes/SGR character
    attributes
  * Block selection appending duplicate newlines when last column
    is selected
  * Bitmap fonts being a bit smaller than they should be in some
    cases
  * Config reload creating alternate screen history instead of
    updating scrollback
  * Crash on Wayland compositors supporting wl_seat version 7+
  * Message bar not hiding after fixing wrong color value in config
  * Tabstops cleared on resize
  * Tabstops not breaking across lines
  * Crash when parsing DCS escape with more than 16 parameters
  * Ignoring of slow touchpad scrolling
  * Selection invisible when starting above viewport and ending
    below it
  * Clipboard not working after TTY switch on Wayland
  * Crash when pasting non UTF-8 string advertised as UTF-8 string
    on Wayland
  * Incorrect modifiers tracking on X11 and macOS, leading to
    'sticky' modifiers
  * Crash when starting on Windows with missing dark mode support
  * Variables XCURSOR_THEME and XCURSOR_SIZE ignored on Wayland
  * Low resolution mouse cursor and decorations on HiDPI Wayland
    outputs
  * Decorations visible when in fullscreen on Wayland
  * Crash on startup with some locales on X11
  * Shrinking terminal height in alt screen deleting primary screen
    content
* Wed Jan 22 2020 Martin Rey <mrey@suse.com>
- Update to 0.4.1
  * Adapt cargo config
- Packaging:
  * Added compatibility logo variants for environments which can't
  render the default SVG
- Added:
  * Terminal escape bindings with combined modifiers for Delete and
  Insert
  * Colored emojis on Linux/BSD
  * Value randr for WINIT_HIDPI_FACTOR, to ignore Xft.dpi and scale
  based on screen dimensions
- Changed:
  * The enable_experimental_conpty_backend config option has been
  replaced with winpty_backend
- Fixed:
  * URLs not truncated with non-matching single quote
  * Absolute file URLs (file:///home) not recognized because of
  leading /
  * Clipboard escape OSC 52 not working with empty clipboard
  parameter
  * Incorrect window size on X11 when waking up from suspend
  * Width of Unicode 11/12 emojis
  * Performance bottleneck when clearing colored rows
  * Crash on clear when scrolled up in history
  * Entire screen getting underlined/stroke out when running clear
  * Slow startup on some Wayland compositors
  * Resize cursor not showing up on Wayland
  * Maximized windows spawning behind system panel on Gnome Wayland
- Removed:
  * Support for 8-bit C1 escape sequences
* Mon Dec 30 2019 Luke Jones <luke@ljones.dev>
- Update to 0.4.0
  * Clean up spec file
  * Minimum rust version is now >= 1.36
  * Include the config example as documentation
  * Add _service file to enable easy updates of vendored sources
  * Include a README.suse-maint
- Added:
  * Block selection mode when Control is held while starting a selection
  * Allow setting general window class on X11 using CLI or config (window.class.general)
  * Config option window.gtk_theme_variant to set GTK theme variant
  * Completions for --class and -t (short title)
  * Change the mouse cursor when hovering over the message bar and its close button
  * Support combined bold and italic text (with font.bold_italic to customize it)
  * Extra bindings for F13-F20
  * Terminal escape bindings with combined modifiers
  * Bindings for ScrollToTop and ScrollToBottom actions
  * ReceiveChar key binding action to insert the key's text character
  * New CLI flag --hold for keeping Alacritty opened after its child process exits
  * Escape sequence to save and restore window title from stack
  * Alternate scroll escape sequence (CSI ? 1007 h / CSI ? 1007 l)
  * Print name of launch command if Alacritty failed to execute it
  * Live reload font settings from config
  * UTF-8 mouse mode escape sequence (CSI ? 1005 h / CSI ? 1005 l)
  * Escape for reading clipboard (OSC 52 ; <s / p / c> ; ? BEL)
  * Set selection clipboard (OSC 52 ; <s / p> ; <BASE64> BEL)
- Changed:
  * Scroll lines out of the visible region instead of deleting them when clearing the screen
- Fixed:
  * GUI programs launched by Alacritty starting in the background on X11
  * Text Cursor position when scrolling
  * Performance issues while resizing Alacritty
  * First unfullscreen action ignored on window launched in fullscreen mode
  * The window is now filled with the background color before displaying
  * Cells sometimes not getting cleared correctly
  * X11 clipboard hanging when mime type is set
  * Debug ref tests are now written to disk regardless of shutdown method
  * Cursor color setting with escape sequence
  * Override default bindings with subset terminal mode match
  * On Linux, respect fontconfig's embeddedbitmap configuration option
  * Selecting trailing tab with semantic expansion
  * URL parser incorrectly handling Markdown URLs and angled brackets
  * Intermediate bytes of CSI sequences not checked
  * Wayland clipboard integration
  * Use text mouse cursor when mouse mode is temporarily disabled with shift
  * Wayland primary selection clipboard not storing text when selection is stopped outside of the window
  * Block URL highlight while a selection is active
  * Bindings for Alt + F1-F12
  * Discard scrolling region escape with bottom above top
  * Opacity always applying to cells with their background color matching the teriminal background
  * Allow semicolons when setting titles using an OSC
  * Background always opaque on X11
  * Skipping redraws on PTY update
  * Not redrawing while resizing on Windows/macOS
  * Decorations none launching an invisible window on Windows
  * Alacritty turning transparent when opening another window on macOS with chunkwm
  * Startup mode Maximized having no effect on Windows
  * Inserting Emojis using Super+. or compose sequences on Windows
  * Change mouse cursor depending on mode with Wayland
  * Hide mouse cursor when typing if the mouse.hide_when_typing option is set on Wayland
  * Glitches when DPI changes on Windows
  * Crash when resuming after suspension
  * Crash when trying to start on X11 with a Wayland compositor running
  * Crash with a virtual display connected on X11
  * Use \ instead of \\ as path separators on Windows for logging config file location
  * Underline/strikeout drawn above visual bell
  * Terminal going transparent during visual bell
  * Selection not being cleared when sending chars through a binding
  * Mouse protocols/encodings not being mutually exclusive within themselves
  * Escape CSI Ps M deleting lines above cursor when at the bottom of the viewport
  * Cell reset not clearing underline, strikeout and foreground color
  * Escape CSI Ps c honored with a wrong Ps
  * Ignore ESC escapes with invalid intermediates
  * Blank lines after each line when pasting from GTK apps on Wayland
- Removed:
  * Bindings for Super/Command + F1-F12
  * Automatic config generation
  * Deprecated scrolling.faux_multiplier, the alternate scroll
    escape can now be used to disable it and scrolling.multiplier
    controls the number of scrolled lines
* Mon Jul 22 2019 Xu Zhao <i@xuzhao.net>
- update to 0.3.3
  Added:
  * Added ToggleFullscreen action
  * A new window option window.startup_mode which controls how the window is created
  * _NET_WM_ICON property is set on X11 now, allowing for WMs to show icons in titlebars
  * Current Git commit hash to alacritty --version
  * Config options window.title and window.class
  * Config option working_directory
  * Config group debug with the options debug.log_level, debug.print_events and debug.ref_test
  * Select until next matching bracket when double-clicking a bracket
  * Added foreground/background escape code request sequences
  Changed:
  * The start_maximized window option is now startup_mode: Maximized
  * Cells with identical foreground and background will now show their text upon selection/inversion
  * Default Window padding to 0x0
  * Moved config option render_timer and persistent_logging to the debug group
  * When the cursor is in the selection, it will be inverted again, making it visible
  Fixed:
  * Double-width characters in URLs only being highlit on the left half
  * PTY size not getting updated when message bar is shown
  * Text Cursor disappearing
  * Incorrect positioning of zero-width characters over double-width characters
  * Mouse mode generating events when the cell has not changed
  * Selections not automatically expanding across double-width characters
  * Text getting recognized as URLs without slashes separating the scheme
  * URL parser dropping trailing slashes from valid URLs
  * UTF-8 BOM skipped when reading config file
  * Terminfo backspace escape sequence (kbs)
  Removed:
  * Deprecated mouse.faux_scrollback_lines config field
  * Deprecated custom_cursor_colors config field
  * Deprecated hide_cursor_when_typing config field
  * Deprecated cursor_style config field
  * Deprecated unfocused_hollow_cursor config field
  * Deprecated dimensions config field
- refresh vendor.tar.xz
- fixed blurred icon on X11
* Mon May 13 2019 Xaver Hellauer <xaver@hellauer.bayern>
- update to 0.3.2
  Fixed:
  * Panic on startup when using Conpty on Windows
* Tue Apr 23 2019 Dag Jönsson <dag@jnsson.eu>
- update to 0.3.1
  Added:
  * Added ScrollLineUp and ScrollLineDown actions for scrolling line by line
  Changed:
  * Alacritty now has a fixed minimum supported Rust version of 1.31.0
  Fixed:
  * Reset scrolling region when the RIS escape sequence is received
  * Subprocess spawning on macros
  * Unnecessary resize at startup
  * Text getting blurry after live-reloading shaders with padding active
  * Resize events are not send to the shell anymore if dimensions haven't
    changed
  * Minor performance issues with underline and strikeout checks
  * Rare bug which would extend underline and strikeout beyond the end of line
  * Cursors not spanning two lines when over double-width characters
  * Incorrect cursor dimensions if the font offset isn't 0
- refresh vendor.tar.xz
- changed buildrequires to reflect project changes
* Tue Apr  9 2019 Dag Jönsson <dagjo270@student.liu.se>
- upate to 0.3.0
  Added:
  * Ability to specify starting position with the --position flag
  * New configuration field window.position allows specifying the starting
    position
  * Added the ability to change the selection color
  * Text will reflow instead of truncating when resizing Alacritty
  * Underline text and change cursor when hovering over URLs with required
    modifiers pressed
  Changed:
  * Clicking on non-alphabetical characters in front of URLs will no longer
    open them
  Fixed
  * Slow startup time on some X11 systems
  * On Wayland, the --title flag will set the Window title now
  * Fix start_maximized option on X11
  * Terminfo support for extended capabilities
  * Crash when decreasing scrollback history in config while scrolled in
    history
  * Scrollback history live reload only working when shrinking lines
- refresh vendor.tar.xz
- man page and completions had been moved
* Fri Mar 22 2019 Matthias Eliasson <elimat@opensuse.org>
- update to 0.2.9
  Changed:
  * Accept fonts which are smaller in width or height than a single pixel
  Fixed:
  * Incorrect font spacing after moving Alacritty between displays
- refresh vendor.tar.xz
- add --path flag to cargo install which is now required
- minor cleanup with spec-cleaner
* Sat Oct 27 2018 avindra@opensuse.org
- update to 0.2.1
  * first non-development release for opensuse. see
    https://github.com/jwilm/alacritty/releases/tag/v0.2.1 for notes
- simplify cargo vendoring
- minor cleanup with spec-cleaner
* Sat Jul 28 2018 avindra@opensuse.org
- update to rev 57a455e5f209dd965fd6b495d7f2b033fd5288c0
  * Don't paste selection when in mouse mode
  * Paste path into terminal when drag & dropping file
  * Set $LANG env var using languageCode, countryCode
  * Update to glutin 0.16.0
  * Allow disabling DPI scaling
  * Add --class and --title CLI parameters
  * Reduce Increase-/DecreaseFontSize step to 0.5
  * Add Copy/Cut/Paste keys
  * Override dynamic_title when --title is specified
  * Change green implementation to use the macro
  * Ignore mouse input if window is unfocused
  * Clippy: move to cargo clippy, remove unnecessary lint
    annotations, enable clippy in font/copypasta crates,
    fix lints
  * Add config for unfocused window cursor change
  * Add support for cursor shape escape sequence
  * Add bright foreground color option
  * Switch from deprecated `std::env::home_dir` to `dirs::home_dir`
  * Allow specifying modifiers for mouse bindings
  * Send newline with NumpadEnter
  * Add support for LCD-V pixel mode
  * Add binding action for hiding the window
  * Add optional dim foreground color
  * Log: Ignore errors when logger can't write to output
  * Log: Replace debug asserts with static_assertions
  * Log: Reduce debug level for release
  * Log: Fix typo in error message
* Wed Apr 25 2018 guillaume.gardet@opensuse.org
- Remove checksums for config.guess and config.sub for aarch64
  and ppc64le since they are updated
* Fri Mar 30 2018 avindra@opensuse.org
- Drop unneeded Requires for fish and zsh completions
* Wed Mar 28 2018 jengelh@inai.de
- Use a single %%setup call.
- Trim filler wording from description.
* Fri Mar 23 2018 avindra@opensuse.org
- update to rev dcc4b750381cd2096b6001cbf94e95a6e6b52ed0
  * fix verbose logging (-v, -vv and -vvv)
* Sun Mar 18 2018 avindra@opensuse.org
- update to rev 6debc4f3351446417d0c4e38173cd9ef0faa71d5
  * fish shell completions
  * enable SRGB support
  * extend SGR and VT200 mouse support
  * switch meta key to alt instead of super
* Tue Mar 13 2018 avindra@opensuse.org
- initial package @ cb05e72be2fcf7e78bff99e4316f19510bf4f502
